@@ -82,6 +82,11 @@ typedef enum {
 #define AS_APP_QUIRK_NOT_REVIEWABLE		(1 << 5)
 #endif
 
+#if !AS_CHECK_VERSION(0,5,15)
+#define AS_APP_QUIRK_HAS_SHORTCUT		(1 << 6)
+#define AS_APP_QUIRK_NOT_LAUNCHABLE		(1 << 7)
+#endif
+
 GQuark		 gs_app_error_quark		(void);
 
 GsApp		*gs_app_new			(const gchar	*id);
@@ -242,7 +247,7 @@ void		 gs_app_add_quirk		(GsApp		*app,
 GError		*gs_app_get_last_error		(GsApp		*app);
 void		 gs_app_set_last_error		(GsApp		*app,
 						 GError		*error);
-
+gboolean	 gs_app_is_installed		(GsApp		*app);
 G_END_DECLS
 
 #endif /* __GS_APP_H */
