@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2013-2014 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -112,8 +112,8 @@ gs_cmd_refine_flag_from_string (const gchar *flag, GError **error)
 {
 	if (g_strcmp0 (flag, "all") == 0)
 		return G_MAXINT32;
-	if (g_strcmp0 (flag, "licence") == 0)
-		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENCE;
+	if (g_strcmp0 (flag, "license") == 0)
+		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE;
 	if (g_strcmp0 (flag, "url") == 0)
 		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_URL;
 	if (g_strcmp0 (flag, "description") == 0)
@@ -140,6 +140,10 @@ gs_cmd_refine_flag_from_string (const gchar *flag, GError **error)
 		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPGRADE_REMOVED;
 	if (g_strcmp0 (flag, "provenance") == 0)
 		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_PROVENANCE;
+	if (g_strcmp0 (flag, "reviews") == 0)
+		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS;
+	if (g_strcmp0 (flag, "review-ratings") == 0)
+		return GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS;
 	g_set_error (error,
 		     GS_PLUGIN_ERROR,
 		     GS_PLUGIN_ERROR_NOT_SUPPORTED,
@@ -171,6 +175,21 @@ gs_cmd_parse_refine_flags (const gchar *extra, GError **error)
 	return refine_flags;
 }
 
+/**
+ * gs_cmd_refresh_flag_from_string:
+ **/
+static GsPluginRefreshFlags
+gs_cmd_refresh_flag_from_string (const gchar *flag)
+{
+	if (flag == NULL || g_strcmp0 (flag, "all") == 0)
+		return G_MAXINT32;
+	if (g_strcmp0 (flag, "metadata") == 0)
+		return GS_PLUGIN_REFRESH_FLAGS_METADATA;
+	if (g_strcmp0 (flag, "payload") == 0)
+		return GS_PLUGIN_REFRESH_FLAGS_PAYLOAD;
+	return GS_PLUGIN_REFRESH_FLAGS_NONE;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -241,7 +260,7 @@ main (int argc, char **argv)
 	/* load plugins */
 	plugin_loader = gs_plugin_loader_new ();
 	gs_plugin_loader_set_location (plugin_loader, "./plugins/.libs");
-	ret = gs_plugin_loader_setup (plugin_loader, &error);
+	ret = gs_plugin_loader_setup (plugin_loader, NULL, &error);
 	if (!ret) {
 		g_print ("Failed to setup plugins: %s\n", error->message);
 		goto out;
@@ -278,7 +297,7 @@ main (int argc, char **argv)
 		}
 	} else if (argc == 3 && g_strcmp0 (argv[1], "action-upgrade-download") == 0) {
 		app = gs_app_new (argv[2]);
-		gs_app_set_kind (app, GS_APP_KIND_DISTRO_UPGRADE);
+		gs_app_set_kind (app, AS_APP_KIND_OS_UPGRADE);
 		ret = gs_plugin_loader_app_action (plugin_loader,
 						   app,
 						   GS_PLUGIN_LOADER_ACTION_UPGRADE_DOWNLOAD,
@@ -301,8 +320,9 @@ main (int argc, char **argv)
 	} else if (argc == 3 && g_strcmp0 (argv[1], "launch") == 0) {
 		app = gs_app_new (argv[2]);
 		for (i = 0; i < repeat; i++) {
-			ret = gs_plugin_loader_app_launch (plugin_loader,
+			ret = gs_plugin_loader_app_action (plugin_loader,
 							   app,
+							   GS_PLUGIN_LOADER_ACTION_LAUNCH,
 							   NULL,
 							   &error);
 			if (!ret)
@@ -415,10 +435,11 @@ main (int argc, char **argv)
 				break;
 			}
 		}
-	} else if (argc == 2 && g_strcmp0 (argv[1], "refresh") == 0) {
+	} else if (argc >= 2 && g_strcmp0 (argv[1], "refresh") == 0) {
+		GsPluginRefreshFlags refresh_flags;
+		refresh_flags = gs_cmd_refresh_flag_from_string (argv[2]);
 		ret = gs_plugin_loader_refresh (plugin_loader, cache_age,
-						GS_PLUGIN_REFRESH_FLAGS_UPDATES,
-						NULL, &error);
+						refresh_flags, NULL, &error);
 	} else {
 		ret = FALSE;
 		g_set_error_literal (&error,
