@@ -62,6 +62,7 @@ app_state_changed_idle (gpointer user_data)
 	case AS_APP_STATE_INSTALLING:
 	case AS_APP_STATE_REMOVING:
 	case AS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_UPDATABLE_LIVE:
 		name = g_strdup_printf ("%s (%s)",
 					gs_app_get_name (tile->app),
 					_("Installed"));
@@ -129,7 +130,7 @@ gs_feature_tile_set_app (GsFeatureTile *tile, GsApp *app)
 	text_shadow = gs_app_get_metadata_item (app, "Featured::text-shadow");
 
 	data = g_string_sized_new (1024);
-	g_string_append (data, ".button.featured-tile {\n");
+	g_string_append (data, ".featured-tile {\n");
 	g_string_append_printf (data, "  border-color: %s;\n", stroke_color);
 	if (text_shadow != NULL)
 		g_string_append_printf (data, "  text-shadow: %s;\n", text_shadow);
@@ -140,7 +141,7 @@ gs_feature_tile_set_app (GsFeatureTile *tile, GsApp *app)
 	g_string_append (data, "  outline-offset: 2px;\n");
 	g_string_append_printf (data, "  background: %s;\n", background);
 	g_string_append (data, "}\n");
-	g_string_append (data, ".button.featured-tile:hover {\n");
+	g_string_append (data, ".featured-tile:hover {\n");
 	g_string_append (data, "  background: linear-gradient(to bottom,\n");
 	g_string_append (data, "			      alpha(#fff,0.16),\n");
 	g_string_append_printf (data,
@@ -183,7 +184,7 @@ gs_feature_tile_class_init (GsFeatureTileClass *klass)
 
 	widget_class->destroy = gs_feature_tile_destroy;
 
-	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/feature-tile.ui");
+	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/gs-feature-tile.ui");
 
 	gtk_widget_class_bind_template_child (widget_class, GsFeatureTile, image);
 	gtk_widget_class_bind_template_child (widget_class, GsFeatureTile, stack);
