@@ -28,6 +28,7 @@
 #include "gs-page.h"
 #include "gs-shell.h"
 #include "gs-utils.h"
+#include "gs-auth-dialog.h"
 
 typedef struct
 {
@@ -55,6 +56,60 @@ gs_page_helper_free (GsPageHelper *helper)
 	g_slice_free (GsPageHelper, helper);
 }
 
+static void
+gs_page_app_installed_cb (GObject *source,
+                          GAsyncResult *res,
+                          gpointer user_data);
+
+static void
+gs_page_install_authenticate_cb (GtkDialog *dialog,
+				 GtkResponseType response_type,
+				 GsPageHelper *helper)
+{
+	GsPagePrivate *priv = gs_page_get_instance_private (helper->page);
+
+	/* unmap the dialog */
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (response_type != GTK_RESPONSE_OK) {
+		gs_page_helper_free (helper);
+		return;
+	}
+	gs_plugin_loader_app_action_async (priv->plugin_loader,
+					   helper->app,
+	                                   GS_PLUGIN_LOADER_ACTION_INSTALL,
+					   priv->cancellable,
+					   gs_page_app_installed_cb,
+					   helper);
+}
+
+static void
+gs_page_app_removed_cb (GObject *source,
+                        GAsyncResult *res,
+                        gpointer user_data);
+
+static void
+gs_page_remove_authenticate_cb (GtkDialog *dialog,
+				GtkResponseType response_type,
+				GsPageHelper *helper)
+{
+	GsPagePrivate *priv = gs_page_get_instance_private (helper->page);
+
+	/* unmap the dialog */
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (response_type != GTK_RESPONSE_OK) {
+		gs_page_helper_free (helper);
+		return;
+	}
+	gs_plugin_loader_app_action_async (priv->plugin_loader,
+					   helper->app,
+	                                   GS_PLUGIN_LOADER_ACTION_REMOVE,
+					   priv->cancellable,
+					   gs_page_app_removed_cb,
+					   helper);
+}
+
 static void
 gs_page_app_installed_cb (GObject *source,
                           GAsyncResult *res,
@@ -72,6 +127,27 @@ gs_page_app_installed_cb (GObject *source,
 	                                          res,
 	                                          &error);
 	if (!ret) {
+		/* try to authenticate then retry */
+		if (g_error_matches (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_AUTH_REQUIRED)) {
+			g_autoptr(GError) error_local = NULL;
+			GtkWidget *dialog;
+			dialog = gs_auth_dialog_new (priv->plugin_loader,
+						     helper->app,
+						     gs_utils_get_error_value (error),
+						     &error_local);
+			if (dialog == NULL) {
+				g_warning ("%s", error_local->message);
+				return;
+			}
+			gs_shell_modal_dialog_present (priv->shell, GTK_DIALOG (dialog));
+			g_signal_connect (dialog, "response",
+					  G_CALLBACK (gs_page_install_authenticate_cb),
+					  g_steal_pointer (&helper));
+			return;
+		}
+
 		g_warning ("failed to install %s: %s",
 		           gs_app_get_id (helper->app),
 		           error->message);
@@ -96,7 +172,7 @@ gs_page_app_installed_cb (GObject *source,
 	}
 
 	/* only show this if the window is not active */
-	if (gs_app_get_state (helper->app) != AS_APP_STATE_QUEUED_FOR_INSTALL &&
+	if (gs_app_is_installed (helper->app) &&
 	    !gs_shell_is_active (priv->shell))
 		gs_app_notify_installed (helper->app);
 
@@ -124,6 +200,27 @@ gs_page_app_removed_cb (GObject *source,
 	                                          res,
 	                                          &error);
 	if (!ret) {
+		/* try to authenticate then retry */
+		if (g_error_matches (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_AUTH_REQUIRED)) {
+			g_autoptr(GError) error_local = NULL;
+			GtkWidget *dialog;
+			dialog = gs_auth_dialog_new (priv->plugin_loader,
+						     helper->app,
+						     gs_utils_get_error_value (error),
+						     &error_local);
+			if (dialog == NULL) {
+				g_warning ("%s", error_local->message);
+				return;
+			}
+			gs_shell_modal_dialog_present (priv->shell, GTK_DIALOG (dialog));
+			g_signal_connect (dialog, "response",
+					  G_CALLBACK (gs_page_remove_authenticate_cb),
+					  g_steal_pointer (&helper));
+			return;
+		}
+
 		g_warning ("failed to remove: %s", error->message);
 		gs_app_notify_failed_modal (helper->app,
 		                            gs_shell_get_window (priv->shell),
