@@ -37,7 +37,6 @@ gs_plugin_loader_get_app_by_id (GsPluginLoader *plugin_loader,
 	gboolean ret;
 
 	app = gs_app_new (id);
-	app = gs_plugin_loader_dedupe (plugin_loader, app);
 	ret = gs_plugin_loader_app_refine (plugin_loader, app, flags,
 					   cancellable, error);
 	if (!ret)
@@ -514,54 +513,6 @@ gs_plugin_loader_app_refine (GsPluginLoader *plugin_loader,
 	return helper.ret;
 }
 
-/**
- * gs_plugin_loader_app_launch_finish_sync:
- **/
-static void
-gs_plugin_loader_app_launch_finish_sync (GsPluginLoader *plugin_loader,
-					 GAsyncResult *res,
-					 GsPluginLoaderHelper *helper)
-{
-	helper->ret = gs_plugin_loader_app_launch_finish (plugin_loader,
-							  res,
-							  helper->error);
-	g_main_loop_quit (helper->loop);
-}
-
-/**
- * gs_plugin_loader_app_launch:
- **/
-gboolean
-gs_plugin_loader_app_launch (GsPluginLoader *plugin_loader,
-			     GsApp *app,
-			     GCancellable *cancellable,
-			     GError **error)
-{
-	GsPluginLoaderHelper helper;
-
-	/* create temp object */
-	helper.context = g_main_context_new ();
-	helper.loop = g_main_loop_new (helper.context, FALSE);
-	helper.error = error;
-
-	g_main_context_push_thread_default (helper.context);
-
-	/* run async method */
-	gs_plugin_loader_app_launch_async (plugin_loader,
-					   app,
-					   cancellable,
-					   (GAsyncReadyCallback) gs_plugin_loader_app_launch_finish_sync,
-					   &helper);
-	g_main_loop_run (helper.loop);
-
-	g_main_context_pop_thread_default (helper.context);
-
-	g_main_loop_unref (helper.loop);
-	g_main_context_unref (helper.context);
-
-	return helper.ret;
-}
-
 /**
  * gs_plugin_loader_app_action_finish_sync:
  **/
