@@ -44,6 +44,7 @@
 
 #include "gs-plugin.h"
 #include "gs-os-release.h"
+#include "gs-utils.h"
 
 /**
  * gs_plugin_status_to_string:
@@ -77,6 +78,32 @@ gs_plugin_set_enabled (GsPlugin *plugin, gboolean enabled)
 	plugin->enabled = enabled;
 }
 
+/**
+ * gs_plugin_add_auth:
+ **/
+void
+gs_plugin_add_auth (GsPlugin *plugin, GsAuth *auth)
+{
+	g_ptr_array_add (plugin->auth_array, g_object_ref (auth));
+}
+
+/**
+ * gs_plugin_get_auth_by_id:
+ **/
+GsAuth *
+gs_plugin_get_auth_by_id (GsPlugin *plugin, const gchar *provider_id)
+{
+	guint i;
+
+	/* match on ID */
+	for (i = 0; i < plugin->auth_array->len; i++) {
+		GsAuth *auth = g_ptr_array_index (plugin->auth_array, i);
+		if (g_strcmp0 (gs_auth_get_provider_id (auth), provider_id) == 0)
+			return auth;
+	}
+	return NULL;
+}
+
 /**
  * gs_plugin_check_distro_id:
  **/
@@ -355,7 +382,7 @@ gs_plugin_app_launch (GsPlugin *plugin, GsApp *app, GError **error)
 			     desktop_id);
 		return FALSE;
 	}
-	appinfo = G_APP_INFO (g_desktop_app_info_new (desktop_id));
+	appinfo = G_APP_INFO (gs_utils_get_desktop_app_info (desktop_id));
 	if (appinfo == NULL) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
