@@ -113,14 +113,12 @@ gs_popular_tile_set_app (GsPopularTile *tile, GsApp *app)
 	if (!app)
 		return;
 
-	if (gs_app_get_rating_kind (tile->app) == GS_APP_RATING_KIND_USER) {
+	if (gs_app_get_rating (tile->app) >= 0) {
+		gtk_widget_set_visible (tile->stars, TRUE);
 		gs_star_widget_set_rating (GS_STAR_WIDGET (tile->stars),
-					   GS_APP_RATING_KIND_USER,
 					   gs_app_get_rating (tile->app));
 	} else {
-		gs_star_widget_set_rating (GS_STAR_WIDGET (tile->stars),
-					   GS_APP_RATING_KIND_KUDOS,
-					   gs_app_get_kudos_percentage (tile->app));
+		gtk_widget_set_visible (tile->stars, FALSE);
 	}
 	gtk_stack_set_visible_child_name (GTK_STACK (tile->stack), "content");
 
@@ -161,7 +159,7 @@ gs_popular_tile_class_init (GsPopularTileClass *klass)
 
 	widget_class->destroy = gs_popular_tile_destroy;
 
-	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/popular-tile.ui");
+	gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Software/gs-popular-tile.ui");
 
 	gtk_widget_class_bind_template_child (widget_class, GsPopularTile, label);
 	gtk_widget_class_bind_template_child (widget_class, GsPopularTile, image);
