@@ -44,7 +44,6 @@ struct _GsScreenshotImage
 	GtkWidget	*label_error;
 	SoupSession	*session;
 	SoupMessage	*message;
-	gchar		*cachedir;
 	gchar		*filename;
 	const gchar	*current_image;
 	gboolean	 use_desktop_background;
@@ -281,16 +280,6 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 	as_screenshot_show_image (ssimg);
 }
 
-/**
- * gs_screenshot_image_set_cachedir:
- **/
-void
-gs_screenshot_image_set_cachedir (GsScreenshotImage *ssimg, const gchar *cachedir)
-{
-	g_free (ssimg->cachedir);
-	ssimg->cachedir = g_strdup (cachedir);
-}
-
 /**
  * gs_screenshot_image_set_screenshot:
  **/
@@ -335,6 +324,19 @@ gs_screenshot_image_set_use_desktop_background (GsScreenshotImage *ssimg,
 	ssimg->use_desktop_background = use_desktop_background;
 }
 
+/**
+ * gs_screenshot_get_cachefn_for_url:
+ **/
+static gchar *
+gs_screenshot_get_cachefn_for_url (const gchar *url)
+{
+	g_autofree gchar *basename = NULL;
+	g_autofree gchar *checksum = NULL;
+	checksum = g_compute_checksum_for_string (G_CHECKSUM_SHA256, url, -1);
+	basename = g_path_get_basename (url);
+	return g_strdup_printf ("%s-%s", checksum, basename);
+}
+
 /**
  * gs_screenshot_image_load_async:
  **/
@@ -347,8 +349,9 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	const gchar *url;
 	gint rc;
 	g_autofree gchar *basename = NULL;
-	g_autofree gchar *cachedir2 = NULL;
+	g_autofree gchar *cachedir_full = NULL;
 	g_autofree gchar *cachedir = NULL;
+	g_autofree gchar *cachedir_thumb = NULL;
 	g_autofree gchar *sizedir = NULL;
 
 	g_return_if_fail (GS_IS_SCREENSHOT_IMAGE (ssimg));
@@ -376,19 +379,26 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 		gs_screenshot_image_set_error (ssimg, _("Screenshot size not found"));
 		return;
 	}
+
+	/* check if the URL points to a local file */
 	url = as_image_get_url (im);
-	basename = g_path_get_basename (url);
+	if (g_str_has_prefix (url, "file://")) {
+		ssimg->filename = g_strdup (url + 7);
+		if (g_file_test (ssimg->filename, G_FILE_TEST_EXISTS)) {
+			as_screenshot_show_image (ssimg);
+			return;
+		}
+	}
+
+	basename = gs_screenshot_get_cachefn_for_url (url);
 	if (ssimg->width == G_MAXUINT || ssimg->height == G_MAXUINT) {
 		sizedir = g_strdup ("unknown");
 	} else {
 		sizedir = g_strdup_printf ("%ux%u", ssimg->width * ssimg->scale, ssimg->height * ssimg->scale);
 	}
-	cachedir = g_build_filename (ssimg->cachedir,
-				     "gnome-software",
-				     "screenshots",
-				     sizedir,
-				     NULL);
-	rc = g_mkdir_with_parents (cachedir, 0700);
+	cachedir = gs_utils_get_cachedir ("screenshots", NULL);
+	cachedir_full = g_build_filename (cachedir, sizedir, NULL);
+	rc = g_mkdir_with_parents (cachedir_full, 0700);
 	if (rc != 0) {
 		/* TRANSLATORS: this is when we try create the cache directory
 		 * but we were out of space or permission was denied */
@@ -397,7 +407,7 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	}
 
 	/* does local file already exist */
-	ssimg->filename = g_build_filename (cachedir, basename, NULL);
+	ssimg->filename = g_build_filename (cachedir_full, basename, NULL);
 	if (g_file_test (ssimg->filename, G_FILE_TEST_EXISTS)) {
 		as_screenshot_show_image (ssimg);
 		return;
@@ -406,14 +416,12 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	/* can we load a blurred smaller version of this straight away */
 	if (ssimg->width > AS_IMAGE_THUMBNAIL_WIDTH &&
 	    ssimg->height > AS_IMAGE_THUMBNAIL_HEIGHT) {
-		cachedir2 = g_build_filename (ssimg->cachedir,
-					      "gnome-software",
-					      "screenshots",
-					      "112x63",
-					      basename,
-					      NULL);
-		if (g_file_test (cachedir2, G_FILE_TEST_EXISTS))
-			gs_screenshot_image_show_blurred (ssimg, cachedir2);
+		cachedir_thumb = g_build_filename (cachedir,
+						   "112x63",
+						   basename,
+						   NULL);
+		if (g_file_test (cachedir_thumb, G_FILE_TEST_EXISTS))
+			gs_screenshot_image_show_blurred (ssimg, cachedir_thumb);
 	}
 
 	/* download file */
@@ -468,7 +476,6 @@ gs_screenshot_image_destroy (GtkWidget *widget)
 	g_clear_object (&ssimg->screenshot);
 	g_clear_object (&ssimg->session);
 
-	g_clear_pointer (&ssimg->cachedir, g_free);
 	g_clear_pointer (&ssimg->filename, g_free);
 
 	GTK_WIDGET_CLASS (gs_screenshot_image_parent_class)->destroy (widget);
@@ -527,7 +534,7 @@ gs_screenshot_image_class_init (GsScreenshotImageClass *klass)
 	widget_class->draw = gs_screenshot_image_draw;
 
 	gtk_widget_class_set_template_from_resource (widget_class,
-						     "/org/gnome/Software/screenshot-image.ui");
+						     "/org/gnome/Software/gs-screenshot-image.ui");
 
 	gtk_widget_class_bind_template_child (widget_class, GsScreenshotImage, stack);
 	gtk_widget_class_bind_template_child (widget_class, GsScreenshotImage, image1);
