@@ -30,6 +30,7 @@
 
 #include "gs-shell-details.h"
 #include "gs-app-addon-row.h"
+#include "gs-auth-dialog.h"
 #include "gs-history-dialog.h"
 #include "gs-screenshot-image.h"
 #include "gs-progress-button.h"
@@ -256,8 +257,7 @@ gs_shell_details_switch_to (GsPage *page, gboolean scroll_up)
 	case AS_APP_STATE_INSTALLED:
 	case AS_APP_STATE_UPDATABLE:
 	case AS_APP_STATE_UPDATABLE_LIVE:
-		if (gs_app_get_kind (self->app) == AS_APP_KIND_DESKTOP ||
-		    gs_app_get_kind (self->app) == AS_APP_KIND_WEB_APP) {
+		if (!gs_app_has_quirk (self->app, AS_APP_QUIRK_NOT_LAUNCHABLE)) {
 			gtk_widget_set_visible (self->button_details_launch, TRUE);
 		} else {
 			gtk_widget_set_visible (self->button_details_launch, FALSE);
@@ -959,24 +959,88 @@ gs_shell_details_refresh_addons (GsShellDetails *self)
 
 static void gs_shell_details_refresh_reviews (GsShellDetails *self);
 
+typedef struct {
+	GsShellDetails		*self;
+	GsReview		*review;
+	GsApp			*app;
+	GsReviewAction		 action;
+} GsShellDetailsReviewHelper;
+
+static void
+gs_shell_details_review_helper_free (GsShellDetailsReviewHelper *helper)
+{
+	g_object_unref (helper->self);
+	g_object_unref (helper->review);
+	g_object_unref (helper->app);
+	g_free (helper);
+}
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GsShellDetailsReviewHelper, gs_shell_details_review_helper_free);
+
+static void
+gs_shell_details_app_set_review_cb (GObject *source,
+				    GAsyncResult *res,
+				    gpointer user_data);
+
+static void
+gs_shell_details_authenticate_cb (GtkDialog *dialog,
+				  GtkResponseType response_type,
+				  GsShellDetailsReviewHelper *helper)
+{
+	/* unmap the dialog */
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	if (response_type != GTK_RESPONSE_OK) {
+		gs_shell_details_review_helper_free (helper);
+		return;
+	}
+	gs_plugin_loader_review_action_async (helper->self->plugin_loader,
+					      helper->app,
+					      helper->review,
+					      helper->action,
+					      helper->self->cancellable,
+					      gs_shell_details_app_set_review_cb,
+					      helper);
+}
+
 /**
  * gs_shell_details_app_set_review_cb:
  **/
 static void
 gs_shell_details_app_set_review_cb (GObject *source,
-				GAsyncResult *res,
-				gpointer user_data)
+				    GAsyncResult *res,
+				    gpointer user_data)
 {
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source);
-	GsShellDetails *self = GS_SHELL_DETAILS (user_data);
+	g_autoptr(GsShellDetailsReviewHelper) helper = (GsShellDetailsReviewHelper *) user_data;
 	g_autoptr(GError) error = NULL;
 
 	if (!gs_plugin_loader_app_action_finish (plugin_loader, res, &error)) {
-		g_warning ("failed to set review %s: %s",
-			   gs_app_get_id (self->app), error->message);
+		/* try to authenticate then retry */
+		if (g_error_matches (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_AUTH_REQUIRED)) {
+			g_autoptr(GError) error_local = NULL;
+			GtkWidget *dialog;
+			dialog = gs_auth_dialog_new (helper->self->plugin_loader,
+						     helper->app,
+						     gs_utils_get_error_value (error),
+						     &error_local);
+			if (dialog == NULL) {
+				g_warning ("%s", error_local->message);
+				return;
+			}
+			gs_shell_modal_dialog_present (helper->self->shell, GTK_DIALOG (dialog));
+			g_signal_connect (dialog, "response",
+					  G_CALLBACK (gs_shell_details_authenticate_cb),
+					  g_steal_pointer (&helper));
+			return;
+		}
+		g_warning ("failed to set review on %s: %s",
+			   gs_app_get_id (helper->app), error->message);
 		return;
 	}
-	gs_shell_details_refresh_reviews (self);
+	gs_shell_details_refresh_reviews (helper->self);
 }
 
 static void
@@ -984,13 +1048,18 @@ gs_shell_details_review_button_clicked_cb (GsReviewRow *row,
 					   GsReviewAction action,
 					   GsShellDetails *self)
 {
+	GsShellDetailsReviewHelper *helper = g_new0 (GsShellDetailsReviewHelper, 1);
+	helper->self = g_object_ref (self);
+	helper->app = g_object_ref (self->app);
+	helper->review = g_object_ref (gs_review_row_get_review (row));
+	helper->action = action;
 	gs_plugin_loader_review_action_async (self->plugin_loader,
-					      self->app,
-					      gs_review_row_get_review (row),
-					      action,
+					      helper->app,
+					      helper->review,
+					      helper->action,
 					      self->cancellable,
 					      gs_shell_details_app_set_review_cb,
-					      self);
+					      helper);
 }
 
 static void
@@ -1429,14 +1498,14 @@ gs_shell_details_review_response_cb (GtkDialog *dialog,
 	g_autofree gchar *text = NULL;
 	g_autoptr(GDateTime) now = NULL;
 	g_autoptr(GsReview) review = NULL;
+	GsShellDetailsReviewHelper *helper;
 	GsReviewDialog *rdialog = GS_REVIEW_DIALOG (dialog);
 
-	/* unmap the dialog */
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-
 	/* not agreed */
-	if (response != GTK_RESPONSE_OK)
+	if (response != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
+	}
 
 	review = gs_review_new ();
 	gs_review_set_summary (review, gs_review_dialog_get_summary (rdialog));
@@ -1448,13 +1517,21 @@ gs_shell_details_review_response_cb (GtkDialog *dialog,
 	gs_review_set_date (review, now);
 
 	/* call into the plugins to set the new value */
+	helper = g_new0 (GsShellDetailsReviewHelper, 1);
+	helper->self = g_object_ref (self);
+	helper->app = g_object_ref (self->app);
+	helper->review = g_object_ref (review);
+	helper->action = GS_REVIEW_ACTION_SUBMIT;
 	gs_plugin_loader_review_action_async (self->plugin_loader,
-					      self->app,
-					      review,
-					      GS_REVIEW_ACTION_SUBMIT,
+					      helper->app,
+					      helper->review,
+					      helper->action,
 					      self->cancellable,
 					      gs_shell_details_app_set_review_cb,
-					      self);
+					      helper);
+
+	/* unmap the dialog */
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 /**
