@@ -275,7 +275,8 @@ gs_shell_installed_switch_to (GsPage *page, gboolean scroll_up)
 	widget = GTK_WIDGET (gtk_builder_get_object (self->builder, "buttonbox_main"));
 	gtk_widget_show (widget);
 
-	gtk_widget_show (self->button_select);
+	gtk_widget_set_visible (self->button_select,
+				gs_utils_is_current_desktop ("GNOME"));
 
 	if (scroll_up) {
 		GtkAdjustment *adj;
@@ -626,6 +627,8 @@ show_folder_dialog (GtkButton *button, GsShellInstalled *self)
 	dialog = gs_app_folder_dialog_new (GTK_WINDOW (toplevel), apps);
 	g_signal_connect_swapped (dialog, "delete-event",
 				  G_CALLBACK (folder_dialog_done), self);
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), dialog);
 	gs_shell_modal_dialog_present (self->shell, GTK_DIALOG (dialog));
 }
 
