@@ -655,6 +655,10 @@ show_update_details (GsApp *app, GsShellUpdates *self)
 	dialog = gs_update_dialog_new (self->plugin_loader);
 	gs_update_dialog_show_update_details (GS_UPDATE_DIALOG (dialog), app);
 	gs_shell_modal_dialog_present (self->shell, GTK_DIALOG (dialog));
+
+	/* just destroy */
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), dialog);
 }
 
 /**
@@ -741,6 +745,7 @@ gs_shell_updates_get_new_updates (GsShellUpdates *self)
 
 	gs_plugin_loader_refresh_async (self->plugin_loader,
 					10 * 60,
+					GS_PLUGIN_REFRESH_FLAGS_INTERACTIVE |
 					GS_PLUGIN_REFRESH_FLAGS_METADATA |
 					GS_PLUGIN_REFRESH_FLAGS_PAYLOAD,
 					self->cancellable_refresh,
@@ -767,6 +772,9 @@ gs_shell_updates_refresh_confirm_cb (GtkDialog *dialog,
 				     GtkResponseType response_type,
 				     GsShellUpdates *self)
 {
+	/* unmap the dialog */
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
 	switch (response_type) {
 	case GTK_RESPONSE_REJECT:
 		/* open the control center */
@@ -782,7 +790,6 @@ gs_shell_updates_refresh_confirm_cb (GtkDialog *dialog,
 	default:
 		g_assert_not_reached ();
 	}
-	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 /**
@@ -1072,8 +1079,8 @@ upgrade_reboot_failed_cb (GObject *source,
                           gpointer user_data)
 {
 	GsShellUpdates *self = (GsShellUpdates *) user_data;
+	GsApp *app;
 	g_autoptr(GError) error = NULL;
-	g_autoptr(GList) apps = NULL;
 	g_autoptr(GVariant) retval = NULL;
 
 	/* get result */
@@ -1086,10 +1093,15 @@ upgrade_reboot_failed_cb (GObject *source,
 			   error->message);
 	}
 
+	app = gs_upgrade_banner_get_app (GS_UPGRADE_BANNER (self->upgrade_banner));
+	if (app == NULL) {
+		g_warning ("no upgrade to cancel");
+		return;
+	}
+
 	/* cancel trigger */
-	apps = gs_update_list_get_apps (GS_UPDATE_LIST (self->list_box_updates));
 	gs_plugin_loader_app_action_async (self->plugin_loader,
-					   GS_APP (apps->data),
+					   app,
 					   GS_PLUGIN_LOADER_ACTION_OFFLINE_UPDATE_CANCEL,
 					   self->cancellable,
 					   cancel_trigger_failed_cb,
