@@ -28,6 +28,7 @@
 
 typedef struct
 {
+	gboolean	 interactive;
 	gint		 rating;
 	GtkWidget	*button1;
 	GtkWidget	*button2;
@@ -64,26 +65,6 @@ gs_star_widget_get_rating (GsStarWidget *star)
 	return priv->rating;
 }
 
-/**
- * gs_star_widget_set_image_rating:
- **/
-static void
-gs_star_widget_set_image_rating (GtkImage *image,
-				 gint value, gint lower, gint higher)
-{
-	GtkStyleContext *context;
-	const gchar *icon_name = "semi-starred-symbolic";
-
-	if (value <= lower)
-		icon_name = "non-starred-symbolic";
-	if (value >= higher)
-		icon_name = "starred-symbolic";
-
-	context = gtk_widget_get_style_context (GTK_WIDGET (image));
-	gtk_style_context_add_class (context, "star");
-	gtk_image_set_from_icon_name (image, icon_name, GTK_ICON_SIZE_MENU);
-}
-
 /**
  * gs_star_widget_set_icon_size:
  **/
@@ -100,6 +81,20 @@ gs_star_widget_set_icon_size (GsStarWidget *star, guint pixel_size)
 	gtk_image_set_pixel_size (GTK_IMAGE (priv->image5), pixel_size);
 }
 
+static void
+gs_star_widget_style_class_enable (GtkWidget *widget, gboolean val)
+{
+	GtkStyleContext *context;
+	context = gtk_widget_get_style_context (widget);
+	if (val) {
+		gtk_style_context_add_class (context, "star-enabled");
+		gtk_style_context_remove_class (context, "star-disabled");
+	} else {
+		gtk_style_context_add_class (context, "star-disabled");
+		gtk_style_context_remove_class (context, "star-enabled");
+	}
+}
+
 /**
  * gs_star_widget_refresh:
  **/
@@ -108,21 +103,31 @@ gs_star_widget_refresh (GsStarWidget *star)
 {
 	GsStarWidgetPrivate *priv;
 	priv = gs_star_widget_get_instance_private (star);
-	gs_star_widget_set_image_rating (GTK_IMAGE (priv->image1),
-					 priv->rating,
-					 0, rate_to_star[0]);
-	gs_star_widget_set_image_rating (GTK_IMAGE (priv->image2),
-					 priv->rating,
-					 rate_to_star[0], rate_to_star[1]);
-	gs_star_widget_set_image_rating (GTK_IMAGE (priv->image3),
-					 priv->rating,
-					 rate_to_star[1], rate_to_star[2]);
-	gs_star_widget_set_image_rating (GTK_IMAGE (priv->image4),
-					 priv->rating,
-					 rate_to_star[2], rate_to_star[3]);
-	gs_star_widget_set_image_rating (GTK_IMAGE (priv->image5),
-					 priv->rating,
-					 rate_to_star[3], rate_to_star[4]);
+
+	gtk_widget_set_sensitive (priv->button1, priv->interactive);
+	gtk_widget_set_sensitive (priv->button2, priv->interactive);
+	gtk_widget_set_sensitive (priv->button3, priv->interactive);
+	gtk_widget_set_sensitive (priv->button4, priv->interactive);
+	gtk_widget_set_sensitive (priv->button5, priv->interactive);
+
+	gs_star_widget_style_class_enable (priv->image1, priv->rating > 0);
+	gs_star_widget_style_class_enable (priv->image2, priv->rating > 20);
+	gs_star_widget_style_class_enable (priv->image3, priv->rating > 40);
+	gs_star_widget_style_class_enable (priv->image4, priv->rating > 60);
+	gs_star_widget_style_class_enable (priv->image5, priv->rating > 80);
+}
+
+/**
+ * gs_star_widget_set_interactive:
+ **/
+void
+gs_star_widget_set_interactive (GsStarWidget *star, gboolean interactive)
+{
+	GsStarWidgetPrivate *priv;
+	g_return_if_fail (GS_IS_STAR_WIDGET (star));
+	priv = gs_star_widget_get_instance_private (star);
+	priv->interactive = interactive;
+	gs_star_widget_refresh (star);
 }
 
 /**
@@ -158,6 +163,9 @@ gs_star_widget_button_clicked_cb (GtkButton *button, GsStarWidget *star)
 	gint rating;
 
 	priv = gs_star_widget_get_instance_private (star);
+	if (!priv->interactive)
+		return;
+
 	rating = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button),
 						     "GsStarWidget::value"));
 	priv->rating = rating;
