@@ -676,6 +676,28 @@ insert_details_widget (GtkMessageDialog *dialog, const gchar *details)
 	g_signal_connect (dialog, "map-event", G_CALLBACK (unset_focus), NULL);
 }
 
+/**
+ * gs_utils_get_error_value:
+ * @error: A GError
+ *
+ * Gets the machine-readable value stored in the error message.
+ * The machine readable string is after the first "@", e.g.
+ * message = "Requires authentication with @aaa"
+ *
+ * Returns: a string, or %NULL
+ */
+const gchar *
+gs_utils_get_error_value (const GError *error)
+{
+	gchar *str;
+	if (error == NULL)
+		return NULL;
+	str = g_strstr_len (error->message, -1, "@");
+	if (str == NULL)
+		return NULL;
+	return (const gchar *) str + 1;
+}
+
 /**
  * gs_utils_show_error_dialog:
  * @parent: transient parent, or NULL for none
@@ -709,4 +731,28 @@ gs_utils_show_error_dialog (GtkWindow *parent,
 	gtk_widget_show (dialog);
 }
 
+/**
+ * gs_utils_get_desktop_app_info:
+ */
+GDesktopAppInfo *
+gs_utils_get_desktop_app_info (const gchar *id)
+{
+	GDesktopAppInfo *app_info;
+
+	/* try to get the standard app-id */
+	app_info = g_desktop_app_info_new (id);
+
+	/* KDE is a special project because it believes /usr/share/applications
+	 * isn't KDE enough. For this reason we support falling back to the
+	 * "kde4-" prefixed ID to avoid educating various self-righteous
+	 * upstreams about the correct ID to use in the AppData file. */
+	if (app_info == NULL) {
+		g_autofree gchar *kde_id = NULL;
+		kde_id = g_strdup_printf ("%s-%s", "kde4", id);
+		app_info = g_desktop_app_info_new (kde_id);
+	}
+
+	return app_info;
+}
+
 /* vim: set noexpandtab: */
