@@ -34,7 +34,6 @@
  */
 
 struct GsPluginPrivate {
-	gsize			 loaded;
 	GDBusConnection		*connection;
 };
 
@@ -57,10 +56,10 @@ gs_plugin_initialize (GsPlugin *plugin)
 }
 
 /**
- * gs_plugin_get_deps:
+ * gs_plugin_order_after:
  */
 const gchar **
-gs_plugin_get_deps (GsPlugin *plugin)
+gs_plugin_order_after (GsPlugin *plugin)
 {
 	static const gchar *deps[] = {
 		"appstream",		/* need pkgname */
@@ -133,10 +132,10 @@ gs_plugin_packagekit_refine_add_history (GsApp *app, GVariant *dict)
 }
 
 /**
- * gs_plugin_load:
+ * gs_plugin_setup:
  */
-static gboolean
-gs_plugin_load (GsPlugin *plugin, GCancellable *cancellable, GError **error)
+gboolean
+gs_plugin_setup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 {
 	plugin->priv->connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM,
 						   cancellable,
@@ -161,14 +160,6 @@ gs_plugin_packagekit_refine (GsPlugin *plugin,
 	g_autoptr(GVariant) result = NULL;
 	g_autoptr(GVariant) tuple = NULL;
 
-	/* already loaded */
-	if (g_once_init_enter (&plugin->priv->loaded)) {
-		ret = gs_plugin_load (plugin, cancellable, error);
-		g_once_init_leave (&plugin->priv->loaded, TRUE);
-		if (!ret)
-			return FALSE;
-	}
-
 	/* get an array of package names */
 	package_names = g_new0 (const gchar *, g_list_length (list) + 1);
 	for (l = list; l != NULL; l = l->next) {
