@@ -260,11 +260,17 @@ gs_plugin_packagekit_add_results (GsPlugin *plugin,
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 			break;
 		case PK_INFO_ENUM_AVAILABLE:
-		case PK_INFO_ENUM_REMOVING:
 			gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 			break;
 		case PK_INFO_ENUM_INSTALLING:
 		case PK_INFO_ENUM_UPDATING:
+		case PK_INFO_ENUM_DOWNGRADING:
+		case PK_INFO_ENUM_OBSOLETING:
+		case PK_INFO_ENUM_UNTRUSTED:
+			break;
+		case PK_INFO_ENUM_UNAVAILABLE:
+		case PK_INFO_ENUM_REMOVING:
+			gs_app_set_state (app, AS_APP_STATE_UNAVAILABLE);
 			break;
 		default:
 			gs_app_set_state (app, AS_APP_STATE_UNKNOWN);
